@@ -72,7 +72,7 @@ def test_sim():
             FieldMonitor(size=(0, 0, 0), center=(0, 0, 0), freqs=[1, 2], name="point"),
             FluxTimeMonitor(size=(1, 1, 0), center=(0, 0, 0), interval=10, name="plane"),
         ],
-        symmetry=(0, -1, 1),
+        symmetry=(0, 0, 0),
         pml_layers=(
             PML(num_layers=20),
             StablePML(num_layers=30),
@@ -146,20 +146,64 @@ def test_sim_grid_size():
     _ = Simulation(size=size, grid_size=(1.0, 1.0, 1.0))
 
 
-@pytest.mark.parametrize("fwidth,log_level", [(0.001, None), (3, 30)])
-def test_sim_frequency_range(caplog, fwidth, log_level):
-    # small fwidth should be inside range, large one should throw warning
+def _test_sim_size():
+
+    with pytest.raises(SetupError):
+        s = Simulation(size=(1, 1, 1), grid_size=(1e-5, 1e-5, 1e-5))
+        s._validate_size()
+
+    with pytest.raises(SetupError):
+        s = Simulation(size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), run_time=1e-7)
+        s._validate_size()
+
+
+def _test_monitor_size():
+
+    with pytest.raises(SetupError):
+        s = Simulation(
+            size=(1, 1, 1),
+            grid_size=(1e-3, 1e-3, 1e-3),
+            monitors=[
+                FieldMonitor(
+                    size=(inf, inf, inf), freqs=np.linspace(0, 200e12, 10000001), name="test"
+                )
+            ],
+        )
+
+        s.validate_contents()
+
+
+@pytest.mark.parametrize("freq, log_level", [(1.5, 30), (2.5, None), (3.5, 30)])
+def test_monitor_medium_frequency_range(caplog, freq, log_level):
+    # monitor frequency above or below a given medium's range should throw a warning
 
     size = (1, 1, 1)
     medium = Medium(frequency_range=(2, 3))
     box = Structure(geometry=Box(size=(0.1, 0.1, 0.1)), medium=medium)
+    mnt = FieldMonitor(size=(0, 0, 0), name="freq", freqs=[freq])
     src = VolumeSource(
-        source_time=GaussianPulse(freq0=2.4, fwidth=fwidth),
+        source_time=GaussianPulse(freq0=2.5, fwidth=0.5),
         size=(0, 0, 0),
         polarization="Ex",
     )
-    _ = Simulation(size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), structures=[box], sources=[src])
+    sim = Simulation(
+        size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), structures=[box], monitors=[mnt], sources=[src]
+    )
+    assert_log_level(caplog, log_level)
 
+
+@pytest.mark.parametrize("fwidth, log_level", [(0.1, 30), (2, None)])
+def test_monitor_simulation_frequency_range(caplog, fwidth, log_level):
+    # monitor frequency outside of the simulation's frequency range should throw a warning
+
+    size = (1, 1, 1)
+    src = VolumeSource(
+        source_time=GaussianPulse(freq0=2.0, fwidth=fwidth),
+        size=(0, 0, 0),
+        polarization="Ex",
+    )
+    mnt = FieldMonitor(size=(0, 0, 0), name="freq", freqs=[1.5])
+    sim = Simulation(size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), monitors=[mnt], sources=[src])
     assert_log_level(caplog, log_level)
 
 
@@ -246,8 +290,13 @@ def test_sim_plane_wave_error():
 def test_sim_structure_extent(caplog, box_size, log_level):
     """Make sure we warn if structure extends exactly to simulation edges."""
 
+    src = VolumeSource(
+        source_time=GaussianPulse(freq0=3e14, fwidth=1e13),
+        size=(0, 0, 0),
+        polarization="Ex",
+    )
     box = Structure(geometry=Box(size=box_size), medium=Medium(permittivity=2))
-    sim = Simulation(size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), structures=[box])
+    sim = Simulation(size=(1, 1, 1), grid_size=(0.1, 0.1, 0.1), structures=[box], sources=[src])
 
     assert_log_level(caplog, log_level)
 
@@ -422,6 +471,25 @@ def test_medium_dispersion_create():
         struct = Structure(geometry=Box(size=(1, 1, 1)), medium=medium)
 
 
+def test_sellmeier_from_dispersion():
+    n = 3.5
+    wvl = 0.5
+    freq = C_0 / wvl
+    dn_dwvl = -0.1
+    with pytest.raises(ValidationError) as e:
+        # Check that postivie dispersion raises an error
+        medium = Sellmeier.from_dispersion(n=n, freq=freq, dn_dwvl=-dn_dwvl)
+
+    # Check that medium properties are as epected
+    medium = Sellmeier.from_dispersion(n=n, freq=freq, dn_dwvl=dn_dwvl)
+    epses = [medium.eps_model(f) for f in [0.99 * freq, freq, 1.01 * freq]]
+    ns = np.sqrt(epses)
+    dn_df = (ns[2] - ns[0]) / 0.02 / freq
+
+    assert np.allclose(ns[1], n)
+    assert np.allclose(-dn_df * C_0 / wvl**2, dn_dwvl)
+
+
 def eps_compare(medium: Medium, expected: Dict, tol: float = 1e-5):
 
     for freq, val in expected.items():
@@ -452,7 +520,7 @@ def test_epsilon_eval():
     eps_compare(material, expected)
 
     # Constant and eps, zero sigma
-    material = Medium(permittivity=1.5 ** 2)
+    material = Medium(permittivity=1.5**2)
     expected = {
         2e14: 2.25,
         5e14: 2.25,
@@ -460,7 +528,7 @@ def test_epsilon_eval():
     eps_compare(material, expected)
 
     # Constant eps and sigma
-    material = Medium(permittivity=1.5 ** 2, conductivity=0.1)
+    material = Medium(permittivity=1.5**2, conductivity=0.1)
     expected = {
         2e14: 2.25 + 8.987552009401353j,
         5e14: 2.25 + 3.5950208037605416j,
