@@ -13,7 +13,7 @@ from .viz import add_ax_if_none
 from .validators import validate_name_str
 
 from ..constants import C_0, pec_val, EPSILON_0, HERTZ, CONDUCTIVITY, PERMITTIVITY, RADPERSEC
-from ..log import log
+from ..log import log, ValidationError
 
 
 def ensure_freq_in_range(eps_model: Callable[[float], complex]) -> Callable[[float], complex]:
@@ -136,7 +136,7 @@ class AbstractMedium(ABC, Tidy3dBaseModel):
         complex
             Complex-valued relative permittivty.
         """
-        eps_real = n ** 2 - k ** 2
+        eps_real = n**2 - k**2
         eps_imag = 2 * n * k
         return eps_real + 1j * eps_imag
 
@@ -268,7 +268,7 @@ class Medium(AbstractMedium):
             Real part of refractive index.
         k : float = 0
             Imaginary part of refrative index.
-        frequency : float
+        freq : float
             Frequency to evaluate permittivity at (Hz).
 
         Returns
@@ -381,13 +381,14 @@ class PoleResidue(DispersiveMedium):
     """A dispersive medium described by the pole-residue pair model.
     The frequency-dependence of the complex-valued permittivity is described by:
 
+    Note
+    ----
     .. math::
+
         \\epsilon(\\omega) = \\epsilon_\\infty - \\sum_i
         \\left[\\frac{c_i}{j \\omega + a_i} +
         \\frac{c_i^*}{j \\omega + a_i^*}\\right]
 
-    where :math:`a_i` and :math:`c_i` are in units of rad/s.
-
     Example
     -------
     >>> pole_res = PoleResidue(eps_inf=2.0, poles=[((1+2j), (3+4j)), ((5+6j), (7+8j))])
@@ -407,19 +408,6 @@ class PoleResidue(DispersiveMedium):
         units=RADPERSEC,
     )
 
-    # @pydantic.validator("poles", always=True)
-    # def convert_complex(cls, val):
-    #     """convert list of poles to complex"""
-
-    #     poles_complex = []
-    #     for (a, c) in val:
-    #         if isinstance(a, ComplexNumber):
-    #             a = a.real + 1j * a.imag
-    #         if isinstance(c, ComplexNumber):
-    #             c = c.real + 1j * c.imag
-    #         poles_complex.append((a, c))
-    #     return poles_complex
-
     @ensure_freq_in_range
     def eps_model(self, frequency: float) -> complex:
         """Complex-valued permittivity as a function of frequency."""
@@ -462,12 +450,12 @@ class Sellmeier(DispersiveMedium):
     """A dispersive medium described by the Sellmeier model.
     The frequency-dependence of the refractive index is described by:
 
+    Note
+    ----
     .. math::
 
         n(\\lambda)^2 = 1 + \\sum_i \\frac{B_i \\lambda^2}{\\lambda^2 - C_i}
 
-    where :math:`\\lambda` is in microns, :math:`B_i` is unitless and :math:`C_i` is in microns^2.
-
     Example
     -------
     >>> sellmeier_medium = Sellmeier(coeffs=[(1,2), (3,4)])
@@ -475,14 +463,15 @@ class Sellmeier(DispersiveMedium):
     """
 
     coeffs: List[Tuple[float, PositiveFloat]] = pydantic.Field(
-        title="Coefficients", description="List of Sellmeier (:math:`B_i, C_i`) coefficients."
+        title="Coefficients",
+        description="List of Sellmeier (:math:`B_i, C_i`) coefficients (unitless, microns^2).",
     )
 
     def _n_model(self, frequency: float) -> complex:
         """Complex-valued refractive index as a function of frequency."""
 
         wvl = C_0 / frequency
-        wvl2 = wvl ** 2
+        wvl2 = wvl**2
         n_squared = 1.0
         for (B, C) in self.coeffs:
             n_squared += B * wvl2 / (wvl2 - C)
@@ -518,17 +507,51 @@ class Sellmeier(DispersiveMedium):
             name=self.name,
         )
 
+    @classmethod
+    def from_dispersion(cls, n: float, freq: float, dn_dwvl: float = 0):
+        """Convert ``n`` and wavelength dispersion ``dn_dwvl`` values at frequency ``freq`` to
+        a single-pole :class:`Sellmeier` medium.
+
+        Parameters
+        ----------
+        n : float
+            Real part of refractive index. Must be larger than or equal to one.
+        dn_dwvl : float = 0
+            Derivative of the refractive index with wavelength (1/um). Must be negative.
+        frequency : float
+            Frequency to evaluate permittivity at (Hz).
+
+        Returns
+        -------
+        :class:`Medium`
+            medium containing the corresponding ``permittivity`` and ``conductivity``.
+        """
+
+        if dn_dwvl >= 0:
+            raise ValidationError("Dispersion ``dn_dwvl`` must be smaller than zero.")
+        if n < 1:
+            raise ValidationError("Refractive index ``n`` cannot be smaller than one.")
+
+        wvl = C_0 / freq
+        nsqm1 = n**2 - 1
+        c_coeff = -(wvl**3) * n * dn_dwvl / (nsqm1 - wvl * n * dn_dwvl)
+        b_coeff = (wvl**2 - c_coeff) / wvl**2 * nsqm1
+        coeffs = [(b_coeff, c_coeff)]
+
+        return cls(coeffs=coeffs)
+
 
 class Lorentz(DispersiveMedium):
     """A dispersive medium described by the Lorentz model.
     The frequency-dependence of the complex-valued permittivity is described by:
 
+    Note
+    ----
     .. math::
+
         \\epsilon(f) = \\epsilon_\\infty + \\sum_i
         \\frac{\\Delta\\epsilon_i f_i^2}{f_i^2 - 2jf\\delta_i - f^2}
 
-    where :math:`f, f_i, \\delta_i` are in Hz.
-
     Example
     -------
     >>> lorentz_medium = Lorentz(eps_inf=2.0, coeffs=[(1,2,3), (4,5,6)])
@@ -544,7 +567,7 @@ class Lorentz(DispersiveMedium):
     coeffs: List[Tuple[float, float, float]] = pydantic.Field(
         ...,
         title="Epsilon at Infinity",
-        description="List of (:math:`\\Delta\\epsilon_i, f_i, \\delta_i`) values for model.",
+        description="List of (:math:`\\Delta\\epsilon_i, f_i, \\delta_i`) values for model (Hz).",
     )
 
     @ensure_freq_in_range
@@ -553,7 +576,7 @@ class Lorentz(DispersiveMedium):
 
         eps = self.eps_inf + 0.0j
         for (de, f, delta) in self.coeffs:
-            eps += (de * f ** 2) / (f ** 2 - 2j * frequency * delta - frequency ** 2)
+            eps += (de * f**2) / (f**2 - 2j * frequency * delta - frequency**2)
         return eps
 
     @property
@@ -569,21 +592,15 @@ class Lorentz(DispersiveMedium):
             if d > w:
                 r = np.sqrt(d * d - w * w) + 0j
                 a0 = -d + r
-                c0 = de * w ** 2 / 4 / r
+                c0 = de * w**2 / 4 / r
                 a1 = -d - r
                 c1 = -c0
-                # a0 = self.complex_to_tuple(a0)
-                # c0 = self.complex_to_tuple(c0)
-                # a1 = self.complex_to_tuple(a1)
-                # c1 = self.complex_to_tuple(c1)
                 poles.append((a0, c0))
                 poles.append((a1, c1))
             else:
                 r = np.sqrt(w * w - d * d)
                 a = -d - 1j * r
-                c = 1j * de * w ** 2 / 2 / r
-                # a = self.complex_to_tuple(a)
-                # c = self.complex_to_tuple(c)
+                c = 1j * de * w**2 / 2 / r
                 poles.append((a, c))
 
         return PoleResidue(
@@ -598,12 +615,13 @@ class Drude(DispersiveMedium):
     """A dispersive medium described by the Drude model.
     The frequency-dependence of the complex-valued permittivity is described by:
 
+    Note
+    ----
     .. math::
+
         \\epsilon(f) = \\epsilon_\\infty - \\sum_i
         \\frac{ f_i^2}{f^2 + jf\\delta_i}
 
-    where :math:`f, f_i, \\delta_i` are in Hz.
-
     Example
     -------
     >>> drude_medium = Drude(eps_inf=2.0, coeffs=[(1,2), (3,4)])
@@ -617,7 +635,9 @@ class Drude(DispersiveMedium):
     )
 
     coeffs: List[Tuple[float, PositiveFloat]] = pydantic.Field(
-        ..., title="Coefficients", description="List of (:math:`f_i, \\delta_i`) values for model."
+        ...,
+        title="Coefficients",
+        description="List of (:math:`f_i, \\delta_i`) values for model (Hz).",
     )
 
     @ensure_freq_in_range
@@ -626,7 +646,7 @@ class Drude(DispersiveMedium):
 
         eps = self.eps_inf + 0.0j
         for (f, delta) in self.coeffs:
-            eps -= (f ** 2) / (frequency ** 2 + 1j * frequency * delta)
+            eps -= (f**2) / (frequency**2 + 1j * frequency * delta)
         return eps
 
     @property
@@ -639,17 +659,12 @@ class Drude(DispersiveMedium):
             w = 2 * np.pi * f
             d = 2 * np.pi * delta
 
-            c0 = (w ** 2) / 2 / d + 0j
+            c0 = (w**2) / 2 / d + 0j
             a0 = 0j
 
             c1 = -c0
             a1 = -d + 0j
 
-            # a0 = self.complex_to_tuple(a0)
-            # c0 = self.complex_to_tuple(c0)
-            # a1 = self.complex_to_tuple(a1)
-            # c1 = self.complex_to_tuple(c1)
-
             poles.append((a0, c0))
             poles.append((a1, c1))
 
@@ -665,12 +680,13 @@ class Debye(DispersiveMedium):
     """A dispersive medium described by the Debye model.
     The frequency-dependence of the complex-valued permittivity is described by:
 
+    Note
+    ----
     .. math::
+
         \\epsilon(f) = \\epsilon_\\infty + \\sum_i
         \\frac{\\Delta\\epsilon_i}{1 - jf\\tau_i}
 
-    where :math:`f` is in Hz, and :math:`\\tau_i` is in seconds.
-
     Example
     -------
     >>> debye_medium = Debye(eps_inf=2.0, coeffs=[(1,2),(3,4)])
@@ -686,7 +702,7 @@ class Debye(DispersiveMedium):
     coeffs: List[Tuple[float, PositiveFloat]] = pydantic.Field(
         ...,
         title="Coefficients",
-        description="List of (:math:`\\Delta\\epsilon_i, \\tau_i`) values for model.",
+        description="List of (:math:`\\Delta\\epsilon_i, \\tau_i`) values for model (Hz, sec).",
     )
 
     @ensure_freq_in_range
