@@ -18,18 +18,18 @@ from .medium import Medium, MediumType, AbstractMedium
 from .structure import Structure
 from .source import SourceType, PlaneWave
 from .monitor import MonitorType
-from .pml import PMLTypes, PML
+from .pml import PMLTypes, PML, Absorber
 from .viz import StructMediumParams, StructEpsParams, PMLParams, SymParams
 from .viz import add_ax_if_none, equal_aspect
 
 from ..version import __version__
-from ..constants import C_0, MICROMETER, SECOND
+from ..constants import C_0, MICROMETER, SECOND, pec_val
 from ..log import log, Tidy3dKeyError, SetupError
 
 # for docstring examples
 from .geometry import Sphere, Cylinder, PolySlab  # pylint:disable=unused-import
 from .source import VolumeSource, GaussianPulse  # pylint:disable=unused-import
-from .monitor import FieldMonitor, FluxMonitor, Monitor  # pylint:disable=unused-import
+from .monitor import FieldMonitor, FluxMonitor, Monitor, FreqMonitor  # pylint:disable=unused-import
 
 
 # minimum number of grid points allowed per central wavelength in a medium
@@ -38,6 +38,12 @@ MIN_GRIDS_PER_WVL = 6.0
 # maximum number of mediums supported
 MAX_NUM_MEDIUMS = 200
 
+# maximum numbers of simulation parameters
+MAX_TIME_STEPS = 1e8
+MAX_GRID_CELLS = 20e9
+MAX_CELLS_TIMES_STEPS = 1e17
+MAX_MONITOR_DATA_SIZE_BYTES = 10e9
+
 
 class Simulation(Box):  # pylint:disable=too-many-public-methods
     """Contains all information about Tidy3d simulation.
@@ -181,6 +187,17 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
     """ Validating setup """
 
+    @pydantic.validator("symmetry", always=True)
+    def not_supported_yet(cls, val):
+        """Log an error if non 0 value supplied."""
+        if any(sym_val != 0 for sym_val in val):
+            raise SetupError(
+                "Symmetry not supported in this version of tidy3d, "
+                "but will be included in coming release."
+                "For now, if symmetry is required, use the originl tidy3d."
+            )
+        return val
+
     @pydantic.validator("pml_layers", always=True)
     def set_none_to_zero_layers(cls, val):
         """if any PML layer is None, set it to an empty :class:`PML`."""
@@ -238,14 +255,14 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             struct_bound_min, struct_bound_max = structure.geometry.bounds
             struct_bounds = list(struct_bound_min) + list(struct_bound_max)
 
-            for sim_val, struct_val in zip(sim_bounds, struct_bounds):
+            for istruct, (sim_val, struct_val) in enumerate(zip(sim_bounds, struct_bounds)):
 
                 if np.isclose(sim_val, struct_val):
                     log.warning(
-                        f"structure\n\n{structure}\n\nbounds extend exactly to simulation "
-                        "edges. This can cause unexpected behavior. If intending to extend "
-                        "the structure to infinity along one dimension, use td.inf as a "
-                        "size variable instead to make this explicit."
+                        f"Structure at structures[{istruct}] has bounds that extend exactly to "
+                        "simulation edges. This can cause unexpected behavior. "
+                        "If intending to extend the structure to infinity along one dimension, "
+                        "use td.inf as a size variable instead to make this explicit."
                     )
 
         return val
@@ -278,27 +295,35 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             struct_bound_min, struct_bound_max = structure.geometry.bounds
 
             for source in sources:
-                fmin_src, fmax_src = source.source_time.frequency_range
+                fmin_src, fmax_src = source.source_time.frequency_range()
                 f_average = (fmin_src + fmax_src) / 2.0
                 lambda0 = C_0 / f_average
 
                 zipped = zip(["x", "y", "z"], sim_bound_min, struct_bound_min, val)
                 for axis, sim_val, struct_val, pml in zipped:
-                    if pml.num_layers > 0 and struct_val > sim_val:
+                    if (
+                        pml.num_layers > 0
+                        and struct_val > sim_val
+                        and not isinstance(pml, Absorber)
+                    ):
                         if abs(sim_val - struct_val) < lambda0 / 2:
                             warn(istruct, axis + "-min")
 
                 zipped = zip(["x", "y", "z"], sim_bound_max, struct_bound_max, val)
                 for axis, sim_val, struct_val, pml in zipped:
-                    if pml.num_layers > 0 and struct_val < sim_val:
+                    if (
+                        pml.num_layers > 0
+                        and struct_val < sim_val
+                        and not isinstance(pml, Absorber)
+                    ):
                         if abs(sim_val - struct_val) < lambda0 / 2:
                             warn(istruct, axis + "-max")
 
         return val
 
-    @pydantic.validator("sources", always=True)
-    def _warn_sources_mediums_frequency_range(cls, val, values):
-        """Warn user if any sources have frequency range outside of medium frequency range."""
+    @pydantic.validator("monitors", always=True)
+    def _warn_monitor_mediums_frequency_range(cls, val, values):
+        """Warn user if any DFT monitors have frequencies outside of medium frequency range."""
 
         if val is None:
             return val
@@ -308,25 +333,56 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         medium_bg = values.get("medium")
         mediums = [medium_bg] + [structure.medium for structure in structures]
 
-        for source in val:
-            fmin_src, fmax_src = source.source_time.frequency_range
+        for monitor in val:
+            if not isinstance(monitor, FreqMonitor):
+                continue
+
+            freqs = np.array(monitor.freqs)
             for medium in mediums:
 
                 # skip mediums that have no freq range (all freqs valid)
                 if medium.frequency_range is None:
                     continue
 
-                # make sure medium frequency range includes the source frequency range
+                # make sure medium frequency range includes all monitor frequencies
                 fmin_med, fmax_med = medium.frequency_range
-                if fmin_med > fmin_src or fmax_med < fmax_src:
+                if np.any(freqs < fmin_med) or np.any(freqs > fmax_med):
                     log.warning(
                         f"A medium in the simulation:\n\n({medium})\n\nhas a frequency "
-                        "range that does not fully cover the spectrum of a source:"
-                        f"\n\n({source})\n\nThis can cause innacuracies in the "
-                        "simulation results."
+                        "range that does not fully cover the frequencies of a monitor:"
+                        f"\n\n({monitor})\n\nThis can cause innacuracies in the "
+                        "recorded results."
                     )
         return val
 
+    @pydantic.validator("monitors", always=True)
+    def _warn_monitor_simulation_frequency_range(cls, val, values):
+        """Warn if any DFT monitors have frequencies outside of the simulation frequency range."""
+
+        if val is None:
+            return val
+
+        # Get simulation frequency range
+        source_ranges = [source.source_time.frequency_range() for source in values["sources"]]
+        if len(source_ranges) == 0:
+            log.warning("No sources in simulation.")
+            return val
+
+        freq_min = min([freq_range[0] for freq_range in source_ranges], default=0.0)
+        freq_max = max([freq_range[1] for freq_range in source_ranges], default=0.0)
+
+        for monitor in val:
+            if not isinstance(monitor, FreqMonitor):
+                continue
+
+            freqs = np.array(monitor.freqs)
+            if np.any(freqs < freq_min) or np.any(freqs > freq_max):
+                log.warning(
+                    f"A monitor in the simulation:\n\n({monitor})\n\nhas frequencies "
+                    "outside of the simulation frequency range as defined by the sources."
+                )
+        return val
+
     @pydantic.validator("sources", always=True)
     def _warn_grid_size_too_small(cls, val, values):  # pylint:disable=too-many-locals
         """Warn user if any grid size is too large compared to minimum wavelength in material."""
@@ -341,7 +397,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         mediums = [medium_bg] + [structure.medium for structure in structures]
 
         for source in val:
-            fmin_src, fmax_src = source.source_time.frequency_range
+            fmin_src, fmax_src = source.source_time.frequency_range()
             f_average = (fmin_src + fmax_src) / 2.0
 
             for medium in mediums:
@@ -406,6 +462,56 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         return val
 
+    """ Pre submit validation (before web.upload()) """
+
+    def validate_contents(self) -> None:
+        """Validate the fully initialized simulation is within allowed limits."""
+        self._validate_size()
+        self._validate_monitor_size()
+
+    def _validate_size(self) -> None:
+        """Ensures the simulation is within size limits before simulation is uploaded."""
+
+        num_cells = self.num_cells
+        if num_cells > MAX_GRID_CELLS:
+            raise SetupError(
+                f"Simulation has {num_cells:.2e} computational cells, "
+                f"a maximum of {MAX_GRID_CELLS:.2e} are allowed."
+            )
+
+        num_time_steps = self.num_time_steps
+        if num_time_steps > MAX_TIME_STEPS:
+            raise SetupError(
+                f"Simulation has {num_time_steps:.2e} time steps, "
+                f"a maximum of {MAX_TIME_STEPS:.2e} are allowed."
+            )
+
+        num_cells_times_steps = num_time_steps * num_cells
+        if num_cells_times_steps > MAX_CELLS_TIMES_STEPS:
+            raise SetupError(
+                f"Simulation has {num_cells_times_steps:.2e} grid cells * time steps, "
+                f"a maximum of {MAX_CELLS_TIMES_STEPS:.2e} are allowed."
+            )
+
+    def _validate_monitor_size(self) -> None:
+        """Ensures the monitors arent storing too much data before simulation is uploaded."""
+
+        tmesh = self.tmesh
+
+        total_size_bytes = 0
+        for monitor in self.monitors:
+            monitor_grid = self.discretize(monitor)
+            num_cells = np.prod(monitor_grid.num_cells)
+            monitor_size = monitor.storage_size(num_cells=num_cells, tmesh=tmesh)
+
+            total_size_bytes += monitor_size
+
+        if total_size_bytes > MAX_MONITOR_DATA_SIZE_BYTES:
+            raise SetupError(
+                f"Simulation's monitors have {total_size_bytes:.2e} bytes of estimated storage, "
+                f"a maximum of {MAX_MONITOR_DATA_SIZE_BYTES:.2e} are allowed."
+            )
+
     """ Accounting """
 
     @property
@@ -414,10 +520,12 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         Returns
         -------
-        Set[:class:`AbstractMedium`]
+        List[:class:`AbstractMedium`]
             Set of distinct mediums in the simulation.
         """
-        return {structure.medium for structure in self.structures}
+        medium_dict = {self.medium: None}
+        medium_dict.update({structure.medium: None for structure in self.structures})
+        return list(medium_dict.keys())
 
     @property
     def medium_map(self) -> Dict[MediumType, pydantic.NonNegativeInt]:
@@ -601,6 +709,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             freq = inf
         eps_list = [s.medium.eps_model(freq).real for s in self.structures]
         eps_list.append(self.medium.eps_model(freq).real)
+        eps_list = [eps for eps in eps_list if eps != pec_val]
         eps_max = max(eps_list)
         eps_min = min(eps_list)
         medium_shapes = self._filter_structures_plane(self.structures, x=x, y=y, z=z)
@@ -728,7 +837,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
                 new_kwargs = SymParams(sym_value=sym_value).update_params(**kwargs)
                 ax = sym_box.plot(ax=ax, x=x, y=y, z=z, **new_kwargs)
         ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
-        ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
         return ax
 
     @property
@@ -941,10 +1049,9 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         Returns
         -------
         Tuple[float, float]
-            Minumum and maximum frequencies of the power spectrum of the sources
-            at 5 standard deviations.
+            Minumum and maximum frequencies of the power spectrum of the sources.
         """
-        source_ranges = [source.source_time.frequency_range for source in self.sources]
+        source_ranges = [source.source_time.frequency_range() for source in self.sources]
         freq_min = min([freq_range[0] for freq_range in source_ranges], default=0.0)
         freq_max = max([freq_range[1] for freq_range in source_ranges], default=0.0)
         return (freq_min, freq_max)
@@ -961,7 +1068,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             Time step (seconds).
         """
         dl_mins = [np.min(sizes) for sizes in self.grid.sizes.to_list]
-        dl_sum_inv_sq = sum([1 / dl ** 2 for dl in dl_mins])
+        dl_sum_inv_sq = sum([1 / dl**2 for dl in dl_mins])
         dl_avg = 1 / np.sqrt(dl_sum_inv_sq)
         return self.courant * dl_avg / C_0
 
@@ -977,6 +1084,12 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         dt = self.dt
         return np.arange(0.0, self.run_time + dt, dt)
 
+    @property
+    def num_time_steps(self) -> int:
+        """Number of time steps in simulation."""
+
+        return len(self.tmesh)
+
     def _make_bound_coords_uniform(self, dl, center, size, num_layers):
         """creates coordinate boundaries with uniform mesh (dl is float)"""
 
@@ -1043,6 +1156,18 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         boundaries = Coords(**cell_boundary_dict)
         return Grid(boundaries=boundaries)
 
+    @property
+    def num_cells(self) -> int:
+        """Number of cells in the simulation.
+
+        Returns
+        -------
+        int
+            Number of yee cells in the simulation.
+        """
+
+        return np.prod(self.grid.num_cells)
+
     @staticmethod
     def _add_pml_to_bounds(num_layers: Tuple[int, int], bounds: Coords1D):
         """Append absorber layers to the beginning and end of the simulation bounds
